@@ -25,7 +25,7 @@ def gen_conf(path_to_pdb, home_dir, job_id, pdb_id, conformers, average_rmsd, qu
 
     num_models = len(glob.glob(home_dir+'/'+job_id+"/models/"+pdb_id+"_*.pdb"))
 
-    check_quiet_print(quiet,"generating "+str(conformers)+" conformers for each of "+str(num_models)+" models, ("+str(int(conformers) * int(num_models))+" in total\nprody output:\n)")
+    check_quiet_print(quiet,"generating "+str(conformers)+" conformers for each of "+str(num_models)+" models, ("+str(int(conformers) * int(num_models))+" in total)\nprody output:\n")
 
     #----------------------------------------------------------- generate conformers -------------------------------------------------------------------------
 
@@ -58,8 +58,9 @@ def gen_conf(path_to_pdb, home_dir, job_id, pdb_id, conformers, average_rmsd, qu
         os.chdir(home_dir)
 
     # check conformer generation success
-    if refined_pdbs > 0:
-        check_quiet_print(quiet,"\ngenerated "+str(len(glob.glob(home_dir+"/"+job_id+"/anm/anm*pdb")))+" conformers")
+    generated_conformers = len(glob.glob(home_dir+"/"+job_id+"/anm/anm*pdb"))
+    if generated_conformers > 0:
+        check_quiet_print(quiet,"\ngenerated "+str(generated_conformers)+" conformers")
     else:
         check_quiet_print(quiet,"ERROR failed to generate any conformers, quitting")
         sys.exit(0)
