@@ -15,7 +15,7 @@ from nerrds import run_ansurr
 from nerrds import reweight_bme
 from nerrds.functions import check_quiet_print
 
-nerrds_version = "0.0.74"
+nerrds_version = "0.0.83"
 
 def main():
 
@@ -103,7 +103,7 @@ def main():
     natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\\d+)', s)] # used throughout to loop through files in natural order
 
     now = datetime.now()
-    check_quiet_print(args.quiet,"NERRDS v"+nerrds_version+" "+now.strftime("%d/%m/%Y %H:%M:%S"))
+    check_quiet_print(args.quiet,"\nNERRDS v"+nerrds_version+" "+now.strftime("%d/%m/%Y %H:%M:%S"))
     check_quiet_print(args.quiet," -> pdb: "+path_to_pdb)
     check_quiet_print(args.quiet," -> shifts: "+path_to_shifts)
     
@@ -219,6 +219,8 @@ def main():
         dag.write("PARENT C CHILD D\n")
         dag.close()
 
+        check_quiet_print(quiet,"submitted subsequent processing to the job queue, check NERRDS.log for progress")
+
         run_refine = subprocess.run(["condor_submit_dag", "-f", job_id+".dag"],stdout=subprocess.PIPE, stderr=open(os.devnull, 'w'))
 
     else: # run on this machine in serial 
