@@ -125,15 +125,15 @@ def reweight_ensemble(home_dir,job_id,pdb_id,shifts_id,quiet=False):
 
 
     if len(chosen_ensemble) > 0:
+        check_quiet_print(quiet,"determined an ensemble consisting of "+str(len(chosen_ensemble))+" models with the following weights:")
+        max_pdb_name = '{:>'+str(max([len(i) for i in chosen_ensemble[i]["pdb"]]))+'}'
+        max_model_name = '{:>'+str(max([len(i) for i in chosen_ensemble]))+'}'
+        for model in chosen_ensemble:
+            check_quiet_print(quiet," -> model "+max_model_name.format(model)+" "+max_pdb_name.format(chosen_ensemble[model]["pdb"])+" "+chosen_ensemble[model]["weight"])
+        check_quiet_print(quiet,"the ensemble has been saved here: "+ensemble_dir)
+    else:
         check_quiet_print(quiet,"BME failed to determine an ensemble, quitting")
         sys.exit(0)
-    else:
-        check_quiet_print(quiet,"determined an ensemble consisting of "+str(len(chosen_ensemble))+" models with the following weights:")
-        max_pdb_name = max([len(i) for i in chosen_ensemble[i]["pdb"]])
-        max_model_name = max([len(i) for i in chosen_ensemble])
-        for model in chosen_ensemble:
-            check_quiet_print(quiet,"model "+{:>max_model_name}.format(model)+" "+{:>max_pdb_name}.format(chosen_ensemble[model]["pdb"])+" "+chosen_ensemble[model]["weight"])
-        check_quiet_print(quiet,"the ensemble has been saved here: "+ensemble_dir)
 
 
 if __name__ == "__main__":
